@@ -55,7 +55,7 @@ class CLI_(CLI.CLI):
 
 		# version.
 		elif self.arguments.present(['--version']):
-			self.stop(message=f"{ALIAS} version:"+Files.load(f"{SOURCE_PATH}/.version.py").replace("\n",""), json=Defaults.options.json)
+			self.stop(message=f"{ALIAS} version:"+Files.load(f"{SOURCE_PATH}/.version").replace("\n",""), json=Defaults.options.json)
 
 		# config.
 		#elif self.arguments.present('--config'):
@@ -185,7 +185,7 @@ class CLI_(CLI.CLI):
 				print(f"File path [{fp.path}] does not exist.")
 				sys.exit(1)
 			else:
-				loader = syst3m.console.Loader(f"Retrieving size of {fp.path} ...")
+				loader = Console.Loader(f"Retrieving size of {fp.path} ...")
 				size = fp.size()
 				loader.stop()
 				print(f"Size {fp.path}: {size}")
