@@ -255,6 +255,9 @@ class WebServer(objects.Thread):
 	def token(self):
 		if random.randrange(1, 100) <= 5: 
 			self.__cache__.set(group=self.id, id="token", data=String().generate(length=64, digits=True, capitalize=True))
+		token = self.__cache__.get(group=self.id, id="token")
+		if token == None: 
+			self.__cache__.set(group=self.id, id="token", data=String().generate(length=64, digits=True, capitalize=True))
 		return self.__cache__.get(group=self.id, id="token")
 	@property
 	def running(self):
